#[repr(C)]pub enum StepResult {
Error = 0,
Row = 1,
Done = 2,
Interrupt = 3,
Busy = 4,
}Expand description
StepResult is used to represent the state of a query as it is exposed to the public API of a connection in a virtual table extension. the IO variant is always handled internally and therefore is not included here.
Variants