Connection

Struct Connection 

pub struct Connection(/* private fields */);
Public API for methods to allow extensions to query other tables for the connection that opened the VTable. This value and its resources are cleaned up when the VTable is dropped, so there is no need to manually close the connection.

Implementations

Source

impl Connection

pub fn new(ctx: *mut Conn) -> Self

pub fn prepare(self: &Arc<Self>, sql: &str) -> ExtResult<Statement>

From the included SQL string, prepare a statement for execution.

pub fn execute( self: &Arc<Self>, sql: &str, args: &[Value], ) -> ExtResult<Option<usize>>

Execute a SQL statement with the given arguments. Optionally returns the last inserted rowid for the query.