pub struct ConstraintUsage {
pub argv_index: Option<u32>,
pub omit: bool,
}Expand description
Returned from xBestIndex to describe how the virtual table can use the constraints in the WHERE clause of a query.
Fields
argv_index: Option<u32>1 based index of the argument passed
omit: boolIf true, core can omit this constraint in the vdbe layer.