#[repr(C)]pub struct OrderByInfo {
pub column_index: u32,
pub desc: bool,
}Expand description
Describes an ORDER BY clause in a query involving a virtual table. Passed along with the constraints to xBestIndex.
Fields
column_index: u32The index of the column referenced in the ORDER BY clause.
desc: boolWhether or not the clause is in descending order.