Stmt

Struct Stmt 

#[repr(C)]
pub struct Stmt { pub _conn: *mut c_void, pub _ctx: *mut c_void, pub _bind_args_fn: unsafe extern "C" fn(ctx: *mut Stmt, idx: i32, arg: Value) -> ResultCode, pub _step: unsafe extern "C" fn(ctx: *mut Stmt) -> ResultCode, pub _get_row_values: unsafe extern "C" fn(ctx: *mut Stmt), pub _get_column_names: unsafe extern "C" fn(ctx: *mut Stmt, count: *mut i32) -> *mut *mut c_char, pub _free_current_row: unsafe extern "C" fn(ctx: *mut Stmt), pub _close: unsafe extern "C" fn(ctx: *mut Stmt), pub current_row: *mut Value, pub current_row_len: i32, }
Internal/core use only Extensions should not import or use this type directly

Fields

_conn: *mut c_void_ctx: *mut c_void_bind_args_fn: unsafe extern "C" fn(ctx: *mut Stmt, idx: i32, arg: Value) -> ResultCode_step: unsafe extern "C" fn(ctx: *mut Stmt) -> ResultCode_get_row_values: unsafe extern "C" fn(ctx: *mut Stmt)_get_column_names: unsafe extern "C" fn(ctx: *mut Stmt, count: *mut i32) -> *mut *mut c_char_free_current_row: unsafe extern "C" fn(ctx: *mut Stmt)_close: unsafe extern "C" fn(ctx: *mut Stmt)current_row: *mut Valuecurrent_row_len: i32

Implementations

Source

impl Stmt

pub fn new( conn: *mut c_void, ctx: *mut c_void, bind: unsafe extern "C" fn(ctx: *mut Stmt, idx: i32, arg: Value) -> ResultCode, step: unsafe extern "C" fn(ctx: *mut Stmt) -> ResultCode, rows: unsafe extern "C" fn(ctx: *mut Stmt), names: unsafe extern "C" fn(ctx: *mut Stmt, count: *mut i32) -> *mut *mut c_char, free_row: unsafe extern "C" fn(ctx: *mut Stmt), close: unsafe extern "C" fn(ctx: *mut Stmt), ) -> Self

pub fn close(&mut self)

Close the statement

pub unsafe fn from_ptr(ptr: *mut Stmt) -> ExtResult<&'static mut Self>

Safety

Derefs a null ptr, does a null check first

pub fn to_ptr(&self) -> *mut Stmt

Returns the pointer to the statement.

pub unsafe fn free_current_row(&mut self)

Free the memory for the values obtained from the get_row method. This is easier done on core side because __free_internal_type is ‘core_only’ feature to prevent extensions causing memory issues.

Safety

This fn is unsafe because it derefs a raw pointer after null and length checks. This fn should only be called with the pointer returned from get_row.

pub fn get_row(&self) -> &[Value]

Returns the values from the current row in the prepared statement, should be called after the step() method returns StepResult::Row

pub fn get_column_names(&self) -> Vec<String>

Returns the names of the result columns for the prepared statement.