Value

Struct Value 

pub struct Value { /* private fields */ }

Implementations

Source

impl Value

pub fn null() -> Self

Creates a new Value with type Null

pub fn value_type(&self) -> ValueType

Returns the value type of the Value

pub fn to_float(&self) -> Option<f64>

Returns the float value or casts the relevant value to a float

pub fn to_text(&self) -> Option<&str>

Returns the text value if the Value is the proper type

pub fn is_json(&self) -> bool

pub fn to_blob(&self) -> Option<Vec<u8>>

Returns the blob value if the ValueType is Blob

pub fn to_integer(&self) -> Option<i64>

Returns the value as an integer (casts or converts if possible)

pub fn to_error(&self) -> Option<ResultCode>

Returns the error code if the value is an error

pub fn to_error_details(&self) -> Option<(ResultCode, Option<String>)>

Returns the error code and optional message if the value is an error

pub fn as_bytes(&self) -> Vec<u8>

pub fn from_integer(i: i64) -> Self

Creates a new integer Value from an i64

pub fn from_float(value: f64) -> Self

Creates a new float Value from a f64

pub fn from_text(s: String) -> Self

Creates a new text Value from a String

pub fn from_json(s: String) -> Self

pub fn error(code: ResultCode) -> Self

Creates a new error Value from a ResultCode

pub fn error_with_message(message: String) -> Self

Creates a new error Value from a ResultCode and a message

pub fn from_blob(value: Vec<u8>) -> Self

Creates a new blob Value from a Vec<u8>