Public API for methods to allow extensions to query other tables for
the connection that opened the VTable. This value and its resources are cleaned up when
the VTable is dropped, so there is no need to manually close the connection.
StepResult is used to represent the state of a query as it is exposed
to the public API of a connection in a virtual table extension.
the IO variant is always handled internally and therefore is not included here.
Macro to derive a VTabModule for your extension. This macro will generate
the necessary functions to register your module with core. You must implement
the VTabModule, VTable, and VTabCursor traits.